%define majorver 8.6

Summary: Tcl scripting language development environment
Name: tcl
Version: %{majorver}.7
Release: 1
License: TCL
Group: Development/Languages
URL: http://tcl.sourceforge.net/
Source0: http://downloads.sourceforge.net/sourceforge/%{name}/%{name}-core%{version}-src.tar.gz
Source1: libtcl8.5.so-aix32
Source2: libtcl8.5.so-aix64
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildConflicts: libtommath-devel, libtommath
Provides: tcl(abi) = %{majorver}
Provides: tcl(abi) = 8.5
BuildRequires: zlib-devel >= 1.2.3-7
Requires: zlib >= 1.2.3-7

%define _libdir64 %{_prefix}/lib64

%description
The Tcl (Tool Command Language) provides a powerful platform for
creating integration applications that tie together diverse
applications, protocols, devices, and frameworks. When paired with the
Tk toolkit, Tcl provides a fastest and powerful way to create
cross-platform GUI applications.  Tcl can also be used for a variety
of web-related tasks and for creating powerful command languages for
applications.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Tcl scripting language development environment
Group: Development/Languages
Requires: %{name} = %{version}-%{release}

%description devel
The Tcl (Tool Command Language) provides a powerful platform for
creating integration applications that tie together diverse
applications, protocols, devices, and frameworks. When paired with the
Tk toolkit, Tcl provides a fastest and powerful way to create
cross-platform GUI applications.  Tcl can also be used for a variety
of web-related tasks and for creating powerful command languages for
applications.

The package contains the development files and man pages for tcl.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc_r -q64" or "gcc -maix64".


%prep
%setup -q -n %{name}%{version}
chmod -x generic/tclThreadAlloc.c
mkdir -p ../64bit
cp -r * ../64bit/
mv ../64bit .


%build
# prevent "out of stack space" error
export CFLAGS="-qmaxmem=262144 -DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -O3 -qstrict -I/opt/freeware/include -DTCL_NO_STACK_CHECK"

export CC="cc_r -qcpluscmt"

# first build the 64-bit version
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
export OBJECT_MODE=64
cd 64bit/unix
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --disable-shared --enable-static \
    --enable-threads
make %{?_smp_mflags} lib%{name}%{majorver}.a TCL_LIBRARY=%{_datadir}/%{name}%{majorver}

CreateExportList -X64 %{name}.exp lib%{name}%{majorver}.a
${CC} -qmkshrobj lib%{name}%{majorver}.a -o lib%{name}%{majorver}.so -bE:%{name}.exp -L/opt/freeware/lib -lz -lm
rm -f lib%{name}%{majorver}.a %{name}.exp
/usr/bin/ar -rv lib%{name}%{majorver}.a lib%{name}%{majorver}.so

make %{?_smp_mflags} TCL_LIBRARY=%{_datadir}/%{name}%{majorver}
cd ../..

# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
cd unix
./configure \
    --prefix=%{_prefix} \
    --disable-shared --enable-static \
    --enable-threads
make %{?_smp_mflags} lib%{name}%{majorver}.a TCL_LIBRARY=%{_datadir}/%{name}%{majorver}

CreateExportList -X32 %{name}.exp lib%{name}%{majorver}.a
${CC} -qmkshrobj lib%{name}%{majorver}.a -o lib%{name}%{majorver}.so -bE:%{name}.exp -L/opt/freeware/lib -lz -lm
rm -f lib%{name}%{majorver}.a %{name}.exp
/usr/bin/ar -rv lib%{name}%{majorver}.a lib%{name}%{majorver}.so

make %{?_smp_mflags} TCL_LIBRARY=%{_datadir}/%{name}%{majorver}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

export OBJECT_MODE=64
cd 64bit/unix
make DESTDIR=${RPM_BUILD_ROOT} install TCL_LIBRARY=%{_datadir}/%{name}%{majorver}
mv ${RPM_BUILD_ROOT}%{_bindir}/tclsh%{majorver} ${RPM_BUILD_ROOT}%{_bindir}/tclsh%{majorver}_64
ln -sf tclsh%{majorver}_64 ${RPM_BUILD_ROOT}%{_bindir}/tclsh_64
cd ../..

export OBJECT_MODE=32
cd unix
make DESTDIR=${RPM_BUILD_ROOT} install TCL_LIBRARY=%{_datadir}/%{name}%{majorver}
ln -sf tclsh%{majorver} ${RPM_BUILD_ROOT}%{_bindir}/tclsh

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

ln -sf lib%{name}%{majorver}.so ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.so
ln -sf lib%{name}%{majorver}.so ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}.so

(
  cd ${RPM_BUILD_ROOT}%{_libdir}
  /usr/bin/chmod 0644 lib%{name}%{majorver}.a
  /usr/bin/ar -X32 -x lib%{name}%{majorver}.a

  cd ${RPM_BUILD_ROOT}%{_libdir64}
  /usr/bin/ar -X64 -x lib%{name}%{majorver}.a
  /usr/bin/rm -f lib%{name}%{majorver}.a
)

# add the 64-bit shared library member
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}%{majorver}.a \
    ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}%{majorver}.so \

chmod 0755 ${RPM_BUILD_ROOT}%{_datadir}/%{name}%{majorver}/ldAix

# "convince" tclConfig.sh that we have built shared libraries :-)
/opt/freeware/bin/sed -i 's|TCL_SHARED_BUILD=0|TCL_SHARED_BUILD=1|g' ${RPM_BUILD_ROOT}%{_libdir}/tclConfig.sh
/opt/freeware/bin/sed -i 's|TCL_SHARED_BUILD=0|TCL_SHARED_BUILD=1|g' ${RPM_BUILD_ROOT}%{_libdir64}/tclConfig.sh

mkdir -p ${RPM_BUILD_ROOT}%{_libdir}/%{name}%{majorver}
mkdir -p ${RPM_BUILD_ROOT}%{_libdir64}/%{name}%{majorver}

# add the older v8.5 shared libraries for compatibility reasons
# (make sure they're set for LOADONLY with 'strip -e')
cp %{SOURCE1} ${RPM_BUILD_ROOT}%{_libdir}/libtcl8.5.so
/usr/bin/strip -X32 -e ${RPM_BUILD_ROOT}%{_libdir}/libtcl8.5.so
cp %{SOURCE2} ${RPM_BUILD_ROOT}%{_libdir64}/libtcl8.5.so
/usr/bin/strip -X64 -e ${RPM_BUILD_ROOT}%{_libdir64}/libtcl8.5.so

# add compatibility links for version 8.5
(
  cd ${RPM_BUILD_ROOT}%{_libdir}
  ln -s %{name}%{majorver} %{name}8.5
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  ln -s %{name}%{majorver} %{name}8.5
)

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/linux/${dir}
    cd usr/linux/${dir}
    ln -sf ../../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc README changes license.terms
%{_bindir}/tclsh*
%{_libdir}/lib%{name}%{majorver}.a
%{_libdir}/lib*.so
%{_libdir64}/lib*.so
%dir %{_libdir}/%{name}%{majorver}
%dir %{_libdir64}/%{name}%{majorver}
%{_libdir}/%{name}8.5
%{_libdir64}/%{name}8.5
%dir %{_datadir}/%{name}%{majorver}
%{_datadir}/%{name}%{majorver}/*
%dir %{_datadir}/%{name}8
%{_datadir}/%{name}8/*
%{_mandir}/man1/*
%{_mandir}/mann/*
/usr/linux/bin/tclsh*
/usr/linux/lib/lib%{name}%{majorver}.a
/usr/linux/lib/lib*.so
/usr/linux/lib64/lib*.so


%files devel
%defattr(-,root,system,-)
%{_includedir}/*
%{_libdir}/libtclstub*.a
%{_libdir64}/libtclstub*.a
%{_libdir}/%{name}*Config.sh
%{_libdir64}/%{name}*Config.sh
%{_libdir}/pkgconfig/*
%{_libdir64}/pkgconfig/*
%{_mandir}/man3/*
/usr/linux/include/*
/usr/linux/lib/libtclstub*.a
/usr/linux/lib64/libtclstub*.a


%changelog
* Thu Aug 10 2017 Michael Perzl <michael@perzl.org> - 8.6.7-1
- updated to version 8.6.7

* Tue Oct 25 2016 Michael Perzl <michael@perzl.org> - 8.6.6-1
- updated to version 8.6.6

* Tue Oct 25 2016 Michael Perzl <michael@perzl.org> - 8.6.5-1
- updated to version 8.6.5

* Tue Oct 25 2016 Michael Perzl <michael@perzl.org> - 8.6.4-1
- fixed collision with AIX provided tcl.base
- updated to version 8.6.4

* Thu Dec 11 2014 Michael Perzl <michael@perzl.org> - 8.6.3-1
- updated to version 8.6.3

* Tue Sep 23 2014 Michael Perzl <michael@perzl.org> - 8.6.2-1
- updated to version 8.6.2

* Tue Sep 23 2014 Michael Perzl <michael@perzl.org> - 8.6.1-1
- updated to version 8.6.1

* Tue Sep 23 2014 Michael Perzl <michael@perzl.org> - 8.6.0-1
- updated to version 8.6.0

* Wed Nov 21 2012 Michael Perzl <michael@perzl.org> - 8.5.13-1
- updated to version 8.5.13

* Thu Aug 02 2012 Michael Perzl <michael@perzl.org> - 8.5.12-1
- updated to version 8.5.12

* Wed Nov 09 2011 Michael Perzl <michael@perzl.org> - 8.5.11-1
- updated to version 8.5.11

* Fri Jul 01 2011 Michael Perzl <michael@perzl.org> - 8.5.10-1
- updated to version 8.5.10

* Fri Nov 05 2010 Michael Perzl <michael@perzl.org> - 8.5.9-1
- updated to version 8.5.9

* Wed Oct 20 2010 Michael Perzl <michael@perzl.org> - 8.5.8-2
- prevent "out of stack space" error, for details please check out
  http://old.nabble.com/--tcl-Bugs-2942190---TCL-8.5.8-on-AIX-fails-to-run-with-%22out-of-stack-space%22-td27405185.html

* Wed Nov 18 2009 Michael Perzl <michael@perzl.org> - 8.5.8-1
- updated to version 8.5.8

* Wed Jul 01 2009 Michael Perzl <michael@perzl.org> - 8.5.7-1
- updated to version 8.5.7

* Fri Jan 16 2009 Michael Perzl <michael@perzl.org> - 8.5.6-1
- updated to version 8.5.6

* Sat Nov 01 2008 Michael Perzl <michael@perzl.org> - 8.5.5-1
- updated to version 8.5.5

* Mon Aug 18 2008 Michael Perzl <michael@perzl.org> - 8.5.4-1
- updated to version 8.5.4 and included both 32-bit and 64-bit shared objects

* Mon Jul 07 2008 Michael Perzl <michael@perzl.org> - 8.5.3-1
- updated to version 8.5.3

* Thu Apr 24 2008 Michael Perzl <michael@perzl.org> - 8.5.2-1
- first version for AIX V5.1 and higher
